function varargout = ps_LST_thresholding(job,arg)

%     ps_LST_thresholding.m - Compute binary lesion maps, 
%     part of the LST toolbox
%     Copyright (C) 2012  Paul Schmidt
% 
%     This program is free software: you can redistribute it and/or modify
%     it under the terms of the GNU General Public License as published by
%     the Free Software Foundation, either version 3 of the License, or
%     (at your option) any later version.
% 
%     This program is distributed in the hope that it will be useful,
%     but WITHOUT ANY WARRANTY; without even the implied warranty of
%     MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%     GNU General Public License for more details.
% 
%     You should have received a copy of the GNU General Public License
%     along with this program.  If not, see <http://www.gnu.org/licenses/>.

fprintf('Compute binary lesion map (binary threshold = %g) for...\n', job.threshold)
nimgs = numel(job.data_plm_thresh);
for ii = 1:nimgs
    fprintf(job.data_plm_thresh{ii}, '\n');
    [job_pth, job_plm, job_ext] = fileparts(job.data_plm_thresh{ii});
    
    VLes = spm_vol(fullfile(job_pth, [job_plm, job_ext]));
    Les = spm_read_vols(VLes);
    
    % perform thresholding
    if job.threshold > 0
        Les_binary = 1 .* (Les >= job.threshold);
    else
        Les_binary = 1 .* (Les > job.threshold);
    end
    
    % save binary lesion map
    if job.threshold < 1
        if job.threshold < .1
            txt_threshold = ['b_00', num2str(job.threshold*100), '_'];
        else
            txt_threshold = ['b_0', num2str(job.threshold*100), '_'];
        end
    else
        txt_threshold = ['b_', num2str(job.threshold*100), '_'];
    end
   
    VLes(1).fname = fullfile(job_pth, [txt_threshold, job_plm, job_ext(1:4)]);
    VLes(1).dt(1) = 16;
    spm_write_vol(VLes(1), Les_binary);
    
    fprintf('\n');
    
end

c = clock();
disp(['Finished successfully on ', datestr(c)]);
varargout{:} = ['Finished successfully on ', datestr(c)];

return

